==> calendar-v1.7.20.zip: calendar/messages/sk/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Pridať</strong> profilový kalendár',
    '<strong>Choose</strong> target calendar' => '<strong>Vyberte</strong> cieľový kalendár',
    '<strong>Reminder</strong> settings' => 'Nastavenie <strong>Pripomienky</strong>',
    'Add all Space members with status {status}' => 'Pridať všetkých členov priestoru so stavom {status}',
    'Add participants...' => 'Pridať účastníkov...',
    'Added: {users}' => 'Pridaný: {users}',
    'Additional Information for participants' => 'Doplňujúce informácie pre účastníkov',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Pridať kalendár pre súkromné ​​alebo verejné udalosti do vášho profilu a hlavnej ponuky.',
    'Adds an event calendar to this space.' => 'Pridať do tohto priestoru kalendár udalostí.',
    'After (occurrences)' => 'Po (výskyty)',
    'All Day' => 'Celý deň',
    'Allow option \'Decline\'' => 'Povoliť možnosť „Odmietnuť“',
    'Allow option \'Undecided\'' => 'Povoliť možnosť „Nerozhodnutý“',
    'Allows the user to create new calendar entries' => 'Umožňuje používateľovi vytvárať nové záznamy v kalendári',
    'Allows the user to edit/delete existing calendar entries' => 'Umožňuje používateľovi upraviť/vymazať existujúce záznamy v kalendári',
    'Attending' => 'Zúčastním sa',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Pred výberom cieľového kalendára musí byť modul aktivovaný aspoň v jednom priestore.',
    'Birthday' => 'Narodeniny',
    'Calendar' => 'Kalendár',
    'Cancel Event' => 'Zrušiť udalosť',
    'Cannot remove the participant!' => 'Účastníka nie je možné odstrániť!',
    'Create entry' => 'Vytvoriť záznam',
    'Custom reminder' => 'Vlastná pripomienka',
    'Day' => 'Deň',
    'Days' => 'Dni',
    'Default reminder settings' => 'Predvolené nastavenie pripomienky',
    'Delete all events' => 'Odstrániť všetky udalosti',
    'Deleted' => 'Odstránené',
    'Description' => 'Popis',
    'Do you want to install this module on your profile?' => 'Chcete si tento modul nainštalovať do svojho profilu?',
    'Download ICS' => 'Stiahnite si ICS',
    'Edit' => 'Upraviť',
    'Edit Event' => 'Upraviť udalosť',
    'Edit all events' => 'Upraviť všetky udalosti',
    'Edit this and following events' => 'Upravte túto a nasledujúce udalosti',
    'Edit this event' => 'Upraviť túto udalosť',
    'Email' => 'Email',
    'Enable' => 'Povoliť',
    'Enable Reminder' => 'Povoliť Pripomienku',
    'End' => 'Koniec',
    'End Date' => 'Dátum Ukončenia',
    'End Time' => 'Čas Ukončenia',
    'End time must be after start time!' => 'Čas ukončenia musí byť neskorší ako čas začiatku!',
    'Event' => 'Udalosť',
    'Event Type' => 'Typ Udalosti',
    'Event Types' => 'Typy udalostí',
    'Event could not be deleted!' => 'Udalosť sa nepodarilo odstrániť!',
    'Event has been be deleted!' => 'Udalosť bola vymazaná!',
    'Event not found!' => 'Udalosť sa nenašla!',
    'Export as {type}' => 'Exportovať ako {type}',
    'Files' => 'Súbory',
    'Filter by types' => 'Filtrovať podľa typov',
    'Friday' => 'Piatok',
    'Here you can configure default settings for all calendar events.' => 'Tu môžete nakonfigurovať predvolené nastavenie pre všetky udalosti kalendára.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Tu môžete nakonfigurovať globálne predvolené pripomienky. Tieto nastavenia je možné prepísať na úrovni priestoru/profilu.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Tu môžete nakonfigurovať predvolené nastavenie pripomienky pre túto udalosť. Používatelia môžu tieto nastavenia prepísať pomocou odkazu <strong>Nastaviť pripomienku</strong>.',
    'Hour' => 'Hodina',
    'I\'m attending' => 'Som účatníkom',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Ak chcete pridať udalosti do svojho profilu, musíte najskôr povoliť modul kalendára.',
    'Interested' => 'Záujem',
    'Invalid date or time format!' => 'Neplatný formát dátumu alebo času!',
    'Invalid day of month given' => 'Uvedený neplatný deň v mesiaci',
    'Invalid event type id selected.' => 'Vybrali ste neplatné ID typu udalosti.',
    'Invalid frequency given' => 'Uvedené neplatné opakovanie',
    'Invalid interval given' => 'Zadaný neplatný interval',
    'Invalid week day selection' => 'Neplatný výber dňa v týždni',
    'Invite' => 'Pozvať',
    'Invited: {users}' => 'Pozvaní: {users}',
    'List' => 'Zoznam',
    'Location' => 'Poloha',
    'Manage entries' => 'Spravovať záznamy',
    'Maximum number of participants' => 'Maximálny počet účastníkov',
    'Minute' => 'Minúta',
    'Mode' => 'Režim',
    'Monday' => 'Pondelok',
    'Month' => 'Mesiac',
    'Monthly on day {dayOfMonth}' => 'Mesačne v deň {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mesačne v {position} {dayOfWeek}',
    'Months' => 'Mesiace',
    'Never' => 'Nikdy',
    'Next' => 'Ďalej',
    'No new participants were added.' => 'Neboli pridaní žiadni noví účastníci.',
    'No new participants were invited.' => 'Neboli pozvaní žiadni noví účastníci.',
    'No reminder' => 'Žiadna pripomienka',
    'Notify participants about changes' => 'Informovať účastníkov o zmenách',
    'On date' => 'Pri dátume',
    'Participant removed.' => 'Účastník bol odstránený.',
    'Participants' => 'Účastníci',
    'Participation Status' => 'Stav Účasti',
    'Please select new participants.' => 'Vyberte nových účastníkov.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Súkromné ​​udalosti sú viditeľné iba pre vás, a ak je aktivovaný systém priateľstva, aj pre vašich priateľov.',
    'Profile Calendar' => 'Profilový Kalendár',
    'Public' => 'Verejné',
    'Recurring' => 'Opakujúce sa',
    'Reopen Event' => 'Znovu otvoriť udalosť',
    'Repeat every' => 'Opakovať každý',
    'Saturday' => 'Sobota',
    'Set reminder' => 'Nastaviť pripomienku',
    'Sorting' => 'Triedenie',
    'Start Date' => 'Dátum Začiatku',
    'Start Time' => 'Doba Spustenia',
    'Status cannot be updated.' => 'Stav nie je možné aktualizovať.',
    'Status updated.' => 'Stav bol aktualizovaný.',
    'Sunday' => 'Nedeľa',
    'The event has already ended.' => 'Udalosť sa už skončila.',
    'This event does not support recurrent events' => 'Táto udalosť nepodporuje opakovanie',
    'Thursday' => 'Štvrtok',
    'Time Zone' => 'Časové Pásmo',
    'Title' => 'Názov',
    'Today' => 'Dnes',
    'Tuesday' => 'Utorok',
    'Upcoming {type}' => 'Nadchádzajúce {type}',
    'Upcoming {type}: {title}' => 'Nadchádzajúce {type}: {title}',
    'Use default reminder' => 'Použiť predvolenú pripomienku',
    'User birthdays' => 'Narodeniny používateľa',
    'Wednesday' => 'Streda',
    'Week' => 'Týždeň',
    'Weeks' => 'Týždňov',
    'Year' => 'Rok',
    'Years' => 'Rokov',
    'You cannot invite participants!' => 'Nemôžete pozvať účastníkov!',
    'You don\'t have permission to delete this event!' => 'Nemáte povolenie na odstránenie tejto udalosti!',
    'You have an <strong>{type}</strong> coming up' => 'Čaká vás <strong>{type}</strong>',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Máte pred sebou <strong>{type}</strong>: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Boli ste zaregistrovaní na udalosť „{contentTitle}“ v {spaceName} so začiatkom o {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Boli ste zaregistrovaní na udalosť „{contentTitle}“, ktorá sa začína o {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Boli ste zaregistrovaní na udalosť „{contentTitle}“.',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Vaše nastavenie pripomienky pre udalosť: <strong>\'{title}\'</strong>',
    'canceled' => 'zrušené',
    'disabled' => 'zakázaný',
    'first' => 'najprv',
    'forth' => 'ďalej',
    'global' => 'globálny',
    'last' => 'posledný',
    'on weekdays' => 'vo všedné dni',
    'second' => 'druhý',
    'third' => 'tretí',
    '{displayName} Birthday' => 'Narodeniny oslavuje {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vás pridal k udalosti „{contentTitle}“ v priestore {spaceName}, začínajúcej {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vás pridal k udalosti „{contentTitle}“.',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vás pozval na podujatie „{contentTitle}“ v priestore {spaceName}, začínajúcej {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} vás pozval na podujatie „{contentTitle}“.',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Display events within the next X days' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.4.zip: calendar/messages/sk/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Pridať</strong> profilový kalendár',
    '<strong>Choose</strong> target calendar' => '<strong>Vyberte</strong> cieľový kalendár',
    '<strong>Reminder</strong> settings' => 'Nastavenie <strong>Pripomienky</strong>',
    'Add all Space members with status {status}' => 'Pridať všetkých členov priestoru so stavom {status}',
    'Add participants...' => 'Pridať účastníkov...',
    'Added: {users}' => 'Pridaný: {users}',
    'Additional Information for participants' => 'Doplňujúce informácie pre účastníkov',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Pridať kalendár pre súkromné ​​alebo verejné udalosti do vášho profilu a hlavnej ponuky.',
    'Adds an event calendar to this space.' => 'Pridať do tohto priestoru kalendár udalostí.',
    'After (occurrences)' => 'Po (výskyty)',
    'All Day' => 'Celý deň',
    'Allow option \'Decline\'' => 'Povoliť možnosť „Odmietnuť“',
    'Allow option \'Undecided\'' => 'Povoliť možnosť „Nerozhodnutý“',
    'Allows the user to create new calendar entries' => 'Umožňuje používateľovi vytvárať nové záznamy v kalendári',
    'Allows the user to edit/delete existing calendar entries' => 'Umožňuje používateľovi upraviť/vymazať existujúce záznamy v kalendári',
    'Attending' => 'Zúčastním sa',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Pred výberom cieľového kalendára musí byť modul aktivovaný aspoň v jednom priestore.',
    'Birthday' => 'Narodeniny',
    'Calendar' => 'Kalendár',
    'Cancel Event' => 'Zrušiť udalosť',
    'Cannot remove the participant!' => 'Účastníka nie je možné odstrániť!',
    'Create entry' => 'Vytvoriť záznam',
    'Custom reminder' => 'Vlastná pripomienka',
    'Day' => 'Deň',
    'Days' => 'Dni',
    'Default reminder settings' => 'Predvolené nastavenie pripomienky',
    'Delete all events' => 'Odstrániť všetky udalosti',
    'Deleted' => 'Odstránené',
    'Description' => 'Popis',
    'Do you want to install this module on your profile?' => 'Chcete si tento modul nainštalovať do svojho profilu?',
    'Download ICS' => 'Stiahnite si ICS',
    'Edit' => 'Upraviť',
    'Edit Event' => 'Upraviť udalosť',
    'Edit all events' => 'Upraviť všetky udalosti',
    'Edit this and following events' => 'Upravte túto a nasledujúce udalosti',
    'Edit this event' => 'Upraviť túto udalosť',
    'Email' => 'Email',
    'Enable' => 'Povoliť',
    'Enable Reminder' => 'Povoliť Pripomienku',
    'End' => 'Koniec',
    'End Date' => 'Dátum Ukončenia',
    'End Time' => 'Čas Ukončenia',
    'End time must be after start time!' => 'Čas ukončenia musí byť neskorší ako čas začiatku!',
    'Event' => 'Udalosť',
    'Event Type' => 'Typ Udalosti',
    'Event Types' => 'Typy udalostí',
    'Event could not be deleted!' => 'Udalosť sa nepodarilo odstrániť!',
    'Event has been be deleted!' => 'Udalosť bola vymazaná!',
    'Event not found!' => 'Udalosť sa nenašla!',
    'Export as {type}' => 'Exportovať ako {type}',
    'Files' => 'Súbory',
    'Filter by types' => 'Filtrovať podľa typov',
    'Friday' => 'Piatok',
    'Here you can configure default settings for all calendar events.' => 'Tu môžete nakonfigurovať predvolené nastavenie pre všetky udalosti kalendára.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Tu môžete nakonfigurovať globálne predvolené pripomienky. Tieto nastavenia je možné prepísať na úrovni priestoru/profilu.',
    'Hour' => 'Hodina',
    'I\'m attending' => 'Som účatníkom',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Ak chcete pridať udalosti do svojho profilu, musíte najskôr povoliť modul kalendára.',
    'Interested' => 'Záujem',
    'Invalid date or time format!' => 'Neplatný formát dátumu alebo času!',
    'Invalid day of month given' => 'Uvedený neplatný deň v mesiaci',
    'Invalid event type id selected.' => 'Vybrali ste neplatné ID typu udalosti.',
    'Invalid frequency given' => 'Uvedené neplatné opakovanie',
    'Invalid interval given' => 'Zadaný neplatný interval',
    'Invalid week day selection' => 'Neplatný výber dňa v týždni',
    'Invite' => 'Pozvať',
    'Invited: {users}' => 'Pozvaní: {users}',
    'List' => 'Zoznam',
    'Location' => 'Poloha',
    'Manage entries' => 'Spravovať záznamy',
    'Maximum number of participants' => 'Maximálny počet účastníkov',
    'Minute' => 'Minúta',
    'Mode' => 'Režim',
    'Monday' => 'Pondelok',
    'Month' => 'Mesiac',
    'Monthly on day {dayOfMonth}' => 'Mesačne v deň {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mesačne v {position} {dayOfWeek}',
    'Months' => 'Mesiace',
    'Never' => 'Nikdy',
    'Next' => 'Ďalej',
    'No new participants were added.' => 'Neboli pridaní žiadni noví účastníci.',
    'No new participants were invited.' => 'Neboli pozvaní žiadni noví účastníci.',
    'No reminder' => 'Žiadna pripomienka',
    'Notify participants about changes' => 'Informovať účastníkov o zmenách',
    'On date' => 'Pri dátume',
    'Participant removed.' => 'Účastník bol odstránený.',
    'Participants' => 'Účastníci',
    'Participation Status' => 'Stav Účasti',
    'Please select new participants.' => 'Vyberte nových účastníkov.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Súkromné ​​udalosti sú viditeľné iba pre vás, a ak je aktivovaný systém priateľstva, aj pre vašich priateľov.',
    'Profile Calendar' => 'Profilový Kalendár',
    'Public' => 'Verejné',
    'Recurring' => 'Opakujúce sa',
    'Reopen Event' => 'Znovu otvoriť udalosť',
    'Repeat every' => 'Opakovať každý',
    'Saturday' => 'Sobota',
    'Set reminder' => 'Nastaviť pripomienku',
    'Sorting' => 'Triedenie',
    'Start Date' => 'Dátum Začiatku',
    'Start Time' => 'Doba Spustenia',
    'Status cannot be updated.' => 'Stav nie je možné aktualizovať.',
    'Status updated.' => 'Stav bol aktualizovaný.',
    'Sunday' => 'Nedeľa',
    'The event has already ended.' => 'Udalosť sa už skončila.',
    'This event does not support recurrent events' => 'Táto udalosť nepodporuje opakovanie',
    'Thursday' => 'Štvrtok',
    'Time Zone' => 'Časové Pásmo',
    'Title' => 'Názov',
    'Today' => 'Dnes',
    'Tuesday' => 'Utorok',
    'Upcoming {type}' => 'Nadchádzajúce {type}',
    'Upcoming {type}: {title}' => 'Nadchádzajúce {type}: {title}',
    'Use default reminder' => 'Použiť predvolenú pripomienku',
    'User birthdays' => 'Narodeniny používateľa',
    'Wednesday' => 'Streda',
    'Week' => 'Týždeň',
    'Weeks' => 'Týždňov',
    'Year' => 'Rok',
    'Years' => 'Rokov',
    'You cannot invite participants!' => 'Nemôžete pozvať účastníkov!',
    'You don\'t have permission to delete this event!' => 'Nemáte povolenie na odstránenie tejto udalosti!',
    'You have an <strong>{type}</strong> coming up' => 'Čaká vás <strong>{type}</strong>',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Máte pred sebou <strong>{type}</strong>: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Boli ste zaregistrovaní na udalosť „{contentTitle}“ v {spaceName} so začiatkom o {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Boli ste zaregistrovaní na udalosť „{contentTitle}“, ktorá sa začína o {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Boli ste zaregistrovaní na udalosť „{contentTitle}“.',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Vaše nastavenie pripomienky pre udalosť: <strong>\'{title}\'</strong>',
    'canceled' => 'zrušené',
    'disabled' => 'zakázaný',
    'first' => 'najprv',
    'forth' => 'ďalej',
    'global' => 'globálny',
    'last' => 'posledný',
    'on weekdays' => 'vo všedné dni',
    'second' => 'druhý',
    'third' => 'tretí',
    '{displayName} Birthday' => 'Narodeniny oslavuje {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vás pridal k udalosti „{contentTitle}“ v priestore {spaceName}, začínajúcej {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vás pridal k udalosti „{contentTitle}“.',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vás pozval na podujatie „{contentTitle}“ v priestore {spaceName}, začínajúcej {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} vás pozval na podujatie „{contentTitle}“.',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Display events within the next X days' => '',
    'Filter' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{name} Calendar' => '',
];
